@@ -17,11 +17,10 @@ from zipfile import ZipFile
 import validators
 from PyQt5.QtCore import QRect, QTimer
 from PyQt5.QtWidgets import (QApplication, QCheckBox, QComboBox,
-                             QDialogButtonBox, QFileDialog, QFormLayout,
-                             QGridLayout, QGroupBox, QLabel, QLineEdit,
-                             QMainWindow, QMessageBox, QPushButton,
-                             QRadioButton, QSpinBox, QTabWidget, QVBoxLayout,
-                             QWidget)
+                             QDialogButtonBox, QFileDialog, QGridLayout,
+                             QGroupBox, QLabel, QLineEdit, QMainWindow,
+                             QMessageBox, QPushButton, QRadioButton, QSpinBox,
+                             QTabWidget, QVBoxLayout, QWidget)
 
 cwd = os.getcwd()
 description_filename = ''
@@ -63,14 +62,17 @@ class CreatorGroupWidget(QWidget):
         self.topgroupbox = QGroupBox('LibreOffice Extension Creator')
         topgridbox = QGridLayout()
         self.topgroupbox.setLayout(topgridbox)
+        self.topgroupbox.setObjectName('topgroupbox')
         self.toplabel = QLabel(
             'You can use this program to create '
             'a new non-code LibreOffice extension.')
-        topgridbox.addWidget(self.toplabel)
+        self.toplabel.setObjectName('toplabel')
+        topgridbox.addWidget(self.toplabel, 1, 0)
         self.tab_widget = CreatorTabWidget(self)
         self.bottomgroupbox = QGroupBox()
         bottomgridbox = QGridLayout()
         self.bottomgroupbox.setLayout(bottomgridbox)
+        self.bottomgroupbox.setObjectName('bottomgroupbox')
         self.button_label = QLabel()
         self.button_label.setText(
             'Once you are finished with the data '
@@ -92,7 +94,7 @@ class CreatorGroupWidget(QWidget):
 class CreatorTabWidget(QWidget):
     def __init__(self, parent):
         super(QWidget, self).__init__(parent)
-        self.layout = QFormLayout(self)
+        self.layout = QGridLayout(self)
 
         # Initialize tab screen
         self.tabs = QTabWidget()
@@ -112,6 +114,7 @@ class CreatorTabWidget(QWidget):
         # Create first tab
         gridlayout1 = QGridLayout()
         self.tab1.setLayout(gridlayout1)
+        self.tab1.setObjectName('tab1')
         self.labelnameliboext = QLabel(
             'Name of your LibreOffice Extension, between 8 '
             'and 30 character')
@@ -225,6 +228,7 @@ class CreatorTabWidget(QWidget):
         # Create second tab
         gridlayout2 = QGridLayout()
         self.tab2.setLayout(gridlayout2)
+        self.tab2.setObjectName('tab2')
         licensegroupbox = QGridLayout()
         self.groupboxlicense = QGroupBox()
         self.groupboxlicense.setLayout(licensegroupbox)
@@ -254,6 +258,7 @@ class CreatorTabWidget(QWidget):
         suppressgroupbox = QGridLayout()
         self.groupboxsuppress = QGroupBox()
         self.groupboxsuppress.setLayout(suppressgroupbox)
+        self.groupboxsuppress.setObjectName('suppressgroupbox')
         self.soupdbox = QCheckBox('suppress-on-update')
         self.sifreqbox = QCheckBox('suppress-if-required')
         suppressgroupbox.addWidget(self.soupdbox, 0, 0)
@@ -264,6 +269,7 @@ class CreatorTabWidget(QWidget):
         # Create third tab
         gridlayout3 = QGridLayout()
         self.tab3.setLayout(gridlayout3)
+        self.tab3.setObjectName('tab3')
         self.contentkindbox = QGroupBox(
             'Which kind of content extension to build?')
         gridbox0 = QGridLayout()
@@ -687,7 +693,8 @@ class CreatorTabWidget(QWidget):
 
         path = os.path.join(cwd, 'working_directory', extensionname)
         dir_license_templates = os.path.dirname(__file__)
-        licenseinputpath = os.path.join(dir_license_templates, 'license_files', licensefilename)
+        licenseinputpath = os.path.join(
+            dir_license_templates, 'license_files', licensefilename)
         licenseoutputpath = os.path.join(
             cwd, 'working_directory', extensionname, 'registration',
             licensefilename)
@@ -974,5 +981,8 @@ class CreatorTabWidget(QWidget):
 
 if __name__ == '__main__':
     app = QApplication(sys.argv)
+    app.setStyleSheet(open(os.path.join(
+        os.path.dirname(__file__), 'liboextensioncreator.css')).read())
+
     ex = CreatorApp()
     sys.exit(app.exec_())
